"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AbstractWebviewPanel = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const static_resource_1 = require("@opensumi/ide-core-browser/lib/static-resource");
const ide_theme_1 = require("@opensumi/ide-theme");
const event_1 = require("@opensumi/ide-theme/lib/common/event");
const types_1 = require("./types");
let AbstractWebviewPanel = class AbstractWebviewPanel extends ide_core_browser_1.Disposable {
    setKeybindingDomTarget(target) {
        this._keybindingDomTarget = target;
    }
    constructor(id, options = {}) {
        super();
        this.id = id;
        this._html = '';
        this._onDidFocus = new ide_core_browser_1.Emitter();
        this.onDidFocus = this._onDidFocus.event;
        this._onDidBlur = new ide_core_browser_1.Emitter();
        this.onDidBlur = this._onDidFocus.event;
        this._onDidClickLink = new ide_core_browser_1.Emitter();
        this.onDidClickLink = this._onDidClickLink.event;
        this._onDidScroll = new ide_core_browser_1.Emitter();
        this.onDidScroll = this._onDidScroll.event;
        this._onDidUpdateState = new ide_core_browser_1.Emitter();
        this.onDidUpdateState = this._onDidUpdateState.event;
        this._onRemove = new ide_core_browser_1.Emitter();
        this.onRemove = this._onRemove.event;
        this._isListening = true;
        this._focused = false;
        this._keybindingDomTarget = undefined;
        this._options = options;
    }
    init() {
        this.prepareContainer();
        this.initEvents();
    }
    async postMessage(message) {
        return this._sendToWebview('message', message);
    }
    get options() {
        return this._options;
    }
    onMessage(listener) {
        return this._onWebviewMessage('onmessage', listener);
    }
    initEvents() {
        this._onWebviewMessage('did-click-link', (data) => {
            this._onDidClickLink.fire(new ide_core_browser_1.URI(data));
        });
        this._onWebviewMessage('did-scroll', (data) => {
            this._onDidScroll.fire(data);
        });
        this._onWebviewMessage('do-reload', () => {
            this.doUpdateContent();
        });
        this._onWebviewMessage('load-resource', () => {
            // TODO: 资源相关
        });
        this._onWebviewMessage('load-localhost', () => {
            // TODO: 好像是消息转发
        });
        this._onWebviewMessage('did-focus', () => {
            this.handleFocusChange(true);
        });
        this._onWebviewMessage('did-blur', () => {
            this.handleFocusChange(false);
        });
        this._onWebviewMessage('do-update-state', (state) => {
            this.state = state;
            this._onDidUpdateState.fire(state);
        });
        this._onWebviewMessage('did-keydown', (event) => {
            // Create a fake KeyboardEvent from the data provided
            const emulatedKeyboardEvent = new KeyboardEvent('keydown', event);
            // Force override the target
            Object.defineProperty(emulatedKeyboardEvent, 'target', {
                get: () => this._keybindingDomTarget || this.getDomNode(),
            });
            // And re-dispatch
            window.dispatchEvent(emulatedKeyboardEvent);
        });
        this.updateStyle();
    }
    updateStyle() {
        this.style(this.themeService.getCurrentThemeSync());
        this.addDispose(this.eventBus.on(event_1.ThemeChangedEvent, (e) => {
            this.style(e.payload.theme);
        }));
    }
    getContent() {
        return this._html;
    }
    async setContent(html) {
        this._html = html;
        await this.doUpdateContent();
    }
    doUpdateContent() {
        return this._sendToWebview('content', {
            contents: this.preprocessHtml(this._html),
            options: this._options,
            state: this.state,
        });
    }
    updateOptions(options) {
        this._options = Object.assign(this._options, options);
        this.doUpdateContent();
    }
    layout() {
        throw new Error('Method not implemented.');
    }
    focus() {
        throw new Error('Method not implemented.');
    }
    reload() {
        throw new Error('Method not implemented.');
    }
    handleFocusChange(isFocused) {
        this._focused = isFocused;
        if (this._focused) {
            this._onDidFocus.fire();
        }
        else {
            this._onDidBlur.fire();
        }
    }
    style(theme) {
        const { styles, activeTheme } = this.webviewService.getWebviewThemeData(theme);
        this._sendToWebview('styles', { styles, activeTheme });
    }
    setListenMessages(listening) {
        this._isListening = listening;
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(types_1.IWebviewService),
    tslib_1.__metadata("design:type", Object)
], AbstractWebviewPanel.prototype, "webviewService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_theme_1.IThemeService),
    tslib_1.__metadata("design:type", Object)
], AbstractWebviewPanel.prototype, "themeService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.IEventBus),
    tslib_1.__metadata("design:type", Object)
], AbstractWebviewPanel.prototype, "eventBus", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.AppConfig),
    tslib_1.__metadata("design:type", Object)
], AbstractWebviewPanel.prototype, "appConfig", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(static_resource_1.StaticResourceService),
    tslib_1.__metadata("design:type", static_resource_1.StaticResourceService)
], AbstractWebviewPanel.prototype, "staticResourceService", void 0);
AbstractWebviewPanel = tslib_1.__decorate([
    (0, di_1.Injectable)({ multiple: true }),
    tslib_1.__metadata("design:paramtypes", [String, Object])
], AbstractWebviewPanel);
exports.AbstractWebviewPanel = AbstractWebviewPanel;
//# sourceMappingURL=abstract-webview.js.map