"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebviewModuleContribution = void 0;
const tslib_1 = require("tslib");
/* istanbul ignore file */
const di_1 = require("@opensumi/di");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const browser_1 = require("@opensumi/ide-editor/lib/browser");
const types_1 = require("./types");
const webview_service_1 = require("./webview.service");
let WebviewModuleContribution = class WebviewModuleContribution {
    registerResource(resourceService) {
        resourceService.registerResourceProvider({
            scheme: types_1.EDITOR_WEBVIEW_SCHEME,
            provideResource: async (uri) => {
                const existingComponent = this.webviewService.editorWebviewComponents.get(uri.path.toString());
                if (existingComponent) {
                    return existingComponent.resource;
                }
                else {
                    // try revive, 如果无法恢复，会抛错
                    await this.webviewService.tryRestoredWebviewComponent(uri.path.toString());
                    return this.webviewService.editorWebviewComponents.get(uri.path.toString()).resource;
                }
            },
            shouldCloseResource: (resource, openedResources) => {
                let count = 0;
                for (const resources of openedResources) {
                    for (const r of resources) {
                        if (r.uri.scheme === types_1.EDITOR_WEBVIEW_SCHEME && r.uri.toString() === resource.uri.toString()) {
                            count++;
                        }
                        if (count > 1) {
                            return true;
                        }
                    }
                }
                const component = this.webviewService.editorWebviewComponents.get(resource.uri.path.toString());
                if ((component === null || component === void 0 ? void 0 : component.webview) && (0, types_1.isWebview)(component.webview)) {
                    // 只对类 vscode webview 进行 dispose,
                    // loadUrl 的 plainWebview 必须手动 dispose
                    this.webviewService.editorWebviewComponents.get(resource.uri.path.toString()).clear();
                }
                return true;
            },
        });
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(types_1.IWebviewService),
    tslib_1.__metadata("design:type", webview_service_1.WebviewServiceImpl)
], WebviewModuleContribution.prototype, "webviewService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(browser_1.EditorComponentRegistry),
    tslib_1.__metadata("design:type", browser_1.EditorComponentRegistry)
], WebviewModuleContribution.prototype, "editorComponentRegistry", void 0);
WebviewModuleContribution = tslib_1.__decorate([
    (0, ide_core_browser_1.Domain)(browser_1.BrowserEditorContribution)
], WebviewModuleContribution);
exports.WebviewModuleContribution = WebviewModuleContribution;
//# sourceMappingURL=contribution.js.map