"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ElectronWebviewWebviewPanel = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const common_1 = require("../common");
const abstract_webview_1 = require("./abstract-webview");
let ElectronWebviewWebviewPanel = class ElectronWebviewWebviewPanel extends abstract_webview_1.AbstractWebviewPanel {
    constructor(id, options = {}) {
        super(id, options);
        this.id = id;
        this._needReload = false;
        this._iframeDisposer = new ide_core_browser_1.Disposable();
        this.webview = document.createElement('webview');
        this.webview.src = `${common_1.WebviewScheme}://index.html`;
        this.webview.preload = ide_core_browser_1.electronEnv.webviewPreload;
        this.webview.style.border = 'none';
        this.webview.style.width = '100%';
        this.webview.style.position = 'absolute';
        this.webview.style.height = '100%';
        this.webview.style.zIndex = '2';
        super.init();
    }
    prepareContainer() {
        this.clear();
        this._iframeDisposer = new ide_core_browser_1.Disposable();
        this._ready = new Promise((resolve) => {
            this._onWebviewMessage('webview-ready', () => {
                if (this._isReady) {
                    // 这种情况一般是由于iframe在dom中的位置变动导致了重载。
                    // 此时我们需要重新初始化
                    // electronWebview不需要重新监听事件
                    this.updateStyle();
                    this.doUpdateContent();
                }
                this._isReady = true;
                resolve();
            });
        });
        this._needReload = false;
    }
    getDomNode() {
        return this.webview;
    }
    _sendToWebview(channel, data) {
        if (!this._isListening) {
            return;
        }
        this._ready
            .then(() => {
            if (!this.webview) {
                return;
            }
            this.webview.send(channel, data);
        })
            .catch((err) => {
            (0, ide_core_browser_1.getDebugLogger)().error(err);
        });
    }
    _onWebviewMessage(channel, listener) {
        return this._iframeDisposer.addDispose(new ide_core_browser_1.DomListener(this.webview, 'ipc-message', (e) => {
            if (!this.webview) {
                return;
            }
            if (e.channel === channel) {
                if (!this._isListening) {
                    return;
                }
                listener(e.args[0]);
            }
        }));
    }
    appendTo(container) {
        if (this.webview) {
            if (container.style.position === 'static' || !container.style.position) {
                container.style.position = 'relative';
            }
            container.innerHTML = '';
            container.appendChild(this.webview);
            if (this._needReload) {
                this.init();
                this.doUpdateContent();
            }
        }
    }
    preprocessHtml(html) {
        // 将vscode-resource:/User/xxx 转换为 vscode-resource:///User/xxx
        return html.replace(/(["'])vscode-resource:(\/\/|)([^\s'"]+?)(["'])/gi, (_, startQuote, slash, path, endQuote) => `${startQuote}vscode-resource://${path}${endQuote}`);
    }
    remove() {
        if (this.webview) {
            this.webview.remove();
            this._onRemove.fire();
            // remove 只是视图被销毁，但是html，state等内容保留，因此这里之前是改坏了
            // this.dispose();
            this.clear();
            this._needReload = true;
        }
    }
    clear() {
        if (this._iframeDisposer) {
            this._iframeDisposer.dispose();
            this._iframeDisposer = null;
        }
        this._isReady = false;
    }
    dispose() {
        super.dispose();
        if (this._iframeDisposer) {
            this._iframeDisposer.dispose();
        }
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.AppConfig),
    tslib_1.__metadata("design:type", Object)
], ElectronWebviewWebviewPanel.prototype, "config", void 0);
ElectronWebviewWebviewPanel = tslib_1.__decorate([
    (0, di_1.Injectable)({ multiple: true }),
    tslib_1.__metadata("design:paramtypes", [String, Object])
], ElectronWebviewWebviewPanel);
exports.ElectronWebviewWebviewPanel = ElectronWebviewWebviewPanel;
const WebviewHTMLStr = `<!DOCTYPE html>
<html lang="en" style="width: 100%; height: 100%;">

<head>
  <meta charset="UTF-8">
  <meta http-equiv="Content-Security-Policy"
    content="default-src 'self'; script-src 'self'; frame-src 'self'; style-src 'unsafe-inline'; worker-src 'self'; img-src * data: ;  " />

  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <meta http-equiv="X-UA-Compatible" content="ie=edge">
  <title>Webview Panel Container</title>
</head>

<body style="margin: 0; overflow: hidden; width: 100%; height: 100%">
</body>

</html>`;
//# sourceMappingURL=electron-webview-webview.js.map