"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IFrameWebviewPanel = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const abstract_webview_1 = require("./abstract-webview");
let IFrameWebviewPanel = class IFrameWebviewPanel extends abstract_webview_1.AbstractWebviewPanel {
    constructor(id, options = {}) {
        super(id, options);
        this.id = id;
        this._needReload = false;
        this._iframeDisposer = new ide_core_browser_1.Disposable();
        this.iframe = document.createElement('iframe');
        this.iframe.setAttribute('allow', 'autoplay');
        const sandboxRules = new Set(['allow-same-origin', 'allow-scripts']);
        if (options.allowForms) {
            sandboxRules.add('allow-forms');
        }
        this.iframe.setAttribute('sandbox', Array.from(sandboxRules).join(' '));
        this.iframe.setAttribute('src', `${this.config.webviewEndpoint}/index.html?id=${this.id}`);
        this.iframe.style.border = 'none';
        this.iframe.style.width = '100%';
        this.iframe.style.position = 'absolute';
        this.iframe.style.height = '100%';
        this.iframe.style.zIndex = '2';
        super.init();
    }
    prepareContainer() {
        this.clear();
        this._iframeDisposer = new ide_core_browser_1.Disposable();
        this._ready = new Promise((resolve) => {
            this._onWebviewMessage('webview-ready', () => {
                if (this._isReady) {
                    // 这种情况一般是由于iframe在dom中的位置变动导致了重载。
                    // 此时我们需要重新初始化
                    this.initEvents();
                    this.doUpdateContent();
                }
                this._isReady = true;
                resolve();
            });
        });
        this._needReload = false;
    }
    getDomNode() {
        return this.iframe;
    }
    _sendToWebview(channel, data) {
        if (!this._isListening) {
            return;
        }
        this._ready
            .then(() => {
            if (!this.iframe) {
                return;
            }
            this.iframe.contentWindow.postMessage({
                channel,
                data,
            }, '*');
        })
            .catch((err) => {
            (0, ide_core_browser_1.getDebugLogger)().error(err);
        });
    }
    _onWebviewMessage(channel, listener) {
        return this._iframeDisposer.addDispose(new ide_core_browser_1.DomListener(window, 'message', (e) => {
            if (e.data && e.data.target === this.id && e.data.channel === channel) {
                if (!this._isListening) {
                    return;
                }
                listener(e.data.data);
            }
        }));
    }
    appendTo(container) {
        if (this.iframe) {
            if (container.style.position === 'static' || !container.style.position) {
                container.style.position = 'relative';
            }
            container.innerHTML = '';
            container.appendChild(this.iframe);
            if (this._needReload) {
                this.init();
                this.doUpdateContent();
            }
        }
    }
    preprocessHtml(html) {
        return html.replace(/(["'])vscode-resource:([^\s'"]+?)(["'])/gi, (_, startQuote, path, endQuote) => `${startQuote}${this.staticResourceService.resolveStaticResource(ide_core_browser_1.URI.file(path))}${endQuote}`);
    }
    remove() {
        if (this.iframe) {
            this.iframe.remove();
            this._onRemove.fire();
            // remove 只是视图被销毁，但是html，state等内容保留，因此这里之前是改坏了
            // this.dispose();
            this.clear();
            this._needReload = true;
        }
    }
    clear() {
        if (this._iframeDisposer) {
            this._iframeDisposer.dispose();
            this._iframeDisposer = null;
        }
        this._isReady = false;
    }
    dispose() {
        super.dispose();
        if (this._iframeDisposer) {
            this._iframeDisposer.dispose();
        }
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.AppConfig),
    tslib_1.__metadata("design:type", Object)
], IFrameWebviewPanel.prototype, "config", void 0);
IFrameWebviewPanel = tslib_1.__decorate([
    (0, di_1.Injectable)({ multiple: true }),
    tslib_1.__metadata("design:paramtypes", [String, Object])
], IFrameWebviewPanel);
exports.IFrameWebviewPanel = IFrameWebviewPanel;
//# sourceMappingURL=iframe-webview.js.map