"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ElectronPlainWebview = exports.IframePlainWebview = void 0;
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
class IframePlainWebview extends ide_core_browser_1.Disposable {
    get ready() {
        return this._ready.promise;
    }
    constructor() {
        super();
        this._onMessage = new ide_core_browser_1.Emitter();
        this.onMessage = this._onMessage.event;
        this._onRemove = new ide_core_browser_1.Emitter();
        this.onRemove = this._onRemove.event;
        this._onLoadURL = new ide_core_browser_1.Emitter();
        this.onLoadURL = this._onLoadURL.event;
        this._ready = new ide_core_browser_1.Deferred();
        /**
         * Here we create a `outer iframe`, and later we will create an `inner iframe` and append it into outer's child.
         *
         * So we can capture message in the `outer iframe` instead of in the `main renderer`.
         * +---------------------------------------------------------+
         * | Main renderer                                           |
         * |   +---------------------------------------------------+ |
         * |   | Outer iframe        ^                             | |
         * |   |                     | capture message here        | |
         * |   |   +-----------------+---------------------------+ | |
         * |   |   | Inner iframe    |                           | | |
         * |   |   |             postMessage                     | | |
         * |   |   |                                             | | |
         * |   |   +---------------------------------------------+ | |
         * |   +---------------------------------------------------+ |
         * +---------------------------------------------------------+
         */
        this.wrapper = document.createElement('iframe');
        this.wrapper.setAttribute('src', 'javascript:""');
        this.wrapper.style.width = '100%';
        this.wrapper.style.height = '100%';
        this.wrapper.style.display = 'block';
        this.wrapper.style.position = 'absolute';
        this.wrapper.style.border = 'none';
        this.wrapper.style.zIndex = '2';
        const disposer = this.addDispose(new ide_core_browser_1.DomListener(this.wrapper, 'load', () => {
            this.addDispose(new ide_core_browser_1.DomListener(this.wrapper.contentWindow, 'message', (e) => {
                this._onMessage.fire(e.data);
            }));
            this.wrapper.contentDocument.body.style.margin = '0';
            this._ready.resolve();
            disposer.dispose();
        }));
        this.addDispose(this._onMessage);
    }
    get url() {
        return this._url;
    }
    setPartition(value) {
        // noop
    }
    async loadURL(url) {
        if (!this.wrapper) {
            return;
        }
        await this.ready;
        if (!this.wrapper) {
            return;
        }
        this._url = url;
        if (!this._iframe) {
            this._iframe = document.createElement('iframe');
            this._iframe.style.width = '100%';
            this._iframe.style.height = '100%';
            this._iframe.style.display = 'block';
            this._iframe.style.border = 'none';
            this.wrapper.contentWindow.document.body.appendChild(this._iframe);
        }
        this._iframe.setAttribute('src', url);
        this._onLoadURL.fire(url);
        return new Promise((resolve) => {
            this.addDispose(new ide_core_browser_1.DomListener(this._iframe, 'load', () => {
                resolve();
            }));
        });
    }
    getDomNode() {
        return this.wrapper;
    }
    appendTo(container) {
        if (this.wrapper) {
            if (this.wrapper.parentElement) {
                this.wrapper.remove();
            }
        }
        container.innerHTML = '';
        container.appendChild(this.wrapper);
        if (this._url) {
            this.loadURL(this._url);
        }
    }
    dispose() {
        super.dispose();
        if (this.wrapper) {
            this.wrapper.remove();
            this.wrapper = null;
        }
        if (this._iframe) {
            this._iframe.remove();
            this._iframe = null;
        }
    }
    postMessage(message) {
        if (this._iframe) {
            this._iframe.contentWindow.postMessage(message, '*');
        }
    }
    remove() {
        if (this.wrapper) {
            this.wrapper.remove();
            if (this._iframe) {
                this._iframe.remove();
                this._iframe = null;
            }
            this._onRemove.fire();
        }
    }
}
exports.IframePlainWebview = IframePlainWebview;
class ElectronPlainWebview extends ide_core_browser_1.Disposable {
    constructor() {
        super();
        this.webviewDomReady = new ide_core_browser_1.Deferred();
        this._onMessage = new ide_core_browser_1.Emitter();
        this.onMessage = this._onMessage.event;
        this._onRemove = new ide_core_browser_1.Emitter();
        this.onRemove = this._onRemove.event;
        this._onLoadURL = new ide_core_browser_1.Emitter();
        this.onLoadURL = this._onLoadURL.event;
        this.extendAttributes = {};
        this.wrapper = document.createElement('div');
        this.wrapper.style.width = '100%';
        this.wrapper.style.height = '100%';
        this.wrapper.style.display = 'block';
        this.wrapper.style.position = 'absolute';
        this.wrapper.style.border = 'none';
        this.wrapper.style.zIndex = '2';
        this.addDispose(this._onMessage);
    }
    get url() {
        return this._url;
    }
    getDomNode() {
        return this.wrapper;
    }
    getWebviewElement() {
        return this.webview;
    }
    setPartition(value) {
        this.extendAttributes.partition = value;
    }
    async loadURL(url) {
        if (!this.wrapper) {
            return;
        }
        this._url = url;
        if (!this.webview) {
            this.webview = document.createElement('webview');
            this.webview.style.width = '100%';
            this.webview.style.height = '100%';
            this.webview.style.border = 'none';
            this.webview.style.zIndex = '2';
            this.webview.src = url;
            this.webview.preload = ide_core_browser_1.electronEnv.plainWebviewPreload;
            if (this.extendAttributes.partition) {
                this.webview.partition = this.extendAttributes.partition;
            }
            this.wrapper.appendChild(this.webview);
            this.webview.addEventListener('ipc-message', (event) => {
                if (event.channel === 'webview-message') {
                    this._onMessage.fire(event.args[0]);
                }
            });
            this.addDispose(new ide_core_browser_1.DomListener(this.webview, 'dom-ready', () => {
                this.webviewDomReady.resolve();
            }));
            this.addDispose(new ide_core_browser_1.DomListener(this.webview, 'destroyed', () => {
                this.webviewDomReady = new ide_core_browser_1.Deferred();
            }));
        }
        this._url = url;
        if (document.body.contains(this.wrapper)) {
            return this.doLoadURL();
        }
    }
    async doLoadURL() {
        return new Promise(async (resolve) => {
            this.webview.src = this.url;
            const disposer = this.addDispose(new ide_core_browser_1.DomListener(this.webview, 'did-finish-load', () => {
                disposer.dispose();
                this._onLoadURL.fire(this.url);
                resolve();
            }));
        });
    }
    appendTo(container) {
        container.appendChild(this.wrapper);
        if (this._url) {
            this.doLoadURL();
        }
    }
    dispose() {
        this.wrapper.remove();
        this.wrapper = null;
        this.webview.remove();
        this.webview = null;
    }
    postMessage(message) {
        if (this.webview) {
            this.webview.send('webview-message', message);
        }
    }
    remove() {
        if (this.wrapper) {
            this.wrapper.remove();
            this._onRemove.fire();
        }
    }
}
exports.ElectronPlainWebview = ElectronPlainWebview;
//# sourceMappingURL=plain-webview.js.map