"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ElectronPlainWebviewWindow = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const electron_1 = require("@opensumi/ide-core-browser/lib/utils/electron");
const electron_2 = require("@opensumi/ide-core-common/lib/electron");
let ElectronPlainWebviewWindow = class ElectronPlainWebviewWindow extends ide_core_browser_1.Disposable {
    constructor(options, env = {}) {
        super();
        this._closed = false;
        this._onMessage = new ide_core_browser_1.Emitter();
        this.onMessage = this._onMessage.event;
        this._onClosed = new ide_core_browser_1.Emitter();
        this.onClosed = this._onClosed.event;
        this._ready = this.electronMainUIService
            .createBrowserWindow(Object.assign(Object.assign({}, options), { webPreferences: Object.assign({ preload: new ide_core_browser_1.URI(electron_1.electronEnv.plainWebviewPreload).codeUri.fsPath, additionalArguments: [
                    '--additionalEnv=' + JSON.stringify(env),
                    '--parentWindowWebContentsId=' + electron_1.electronEnv.currentWebContentsId,
                ] }, options === null || options === void 0 ? void 0 : options.webPreferences) }))
            .then(async (id) => {
            this._windowId = id;
            this._webContentsId = await this.electronMainUIService.getWebContentsId(this._windowId);
        })
            .then(() => {
            const listener = (event, { from, message }) => {
                if (from === this._windowId) {
                    this._onMessage.fire(message);
                }
            };
            electron_1.electronEnv.ipcRenderer.on('cross-window-webview-message', listener);
            this.addDispose({
                dispose: () => {
                    electron_1.electronEnv.ipcRenderer.removeListener('cross-window-webview-message', listener);
                },
            });
            this.addDispose(this.electronMainUIService.on('windowClosed', (windowId) => {
                if (windowId === this._windowId) {
                    this._closed = true;
                    this._onClosed.fire();
                    this.dispose();
                }
            }));
        });
        this.addDispose(this._onMessage);
        this.addDispose(this._onClosed);
        this.addDispose({
            dispose: () => {
                this._close();
            },
        });
    }
    get ready() {
        return this._ready;
    }
    get url() {
        return this._url;
    }
    async loadURL(url) {
        await this._ready;
        this._url = url;
        return this.electronMainUIService.browserWindowLoadUrl(this._windowId, url);
    }
    async show() {
        return this.electronMainUIService.showBrowserWindow(this._windowId);
    }
    async hide() {
        return this.electronMainUIService.hideBrowserWindow(this._windowId);
    }
    async setSize(size) {
        return this.electronMainUIService.setSize(this._windowId, size);
    }
    async setAlwaysOnTop(flag) {
        return this.electronMainUIService.setAlwaysOnTop(this._windowId, flag);
    }
    async postMessage(message) {
        return this.electronMainUIService.postMessageToBrowserWindow(this._windowId, 'webview-message', message);
    }
    _close() {
        if (this._closed) {
            return;
        }
        try {
            return this.electronMainUIService.closeBrowserWindow(this._windowId);
        }
        catch (e) {
            // ignore
        }
    }
    get windowId() {
        return this._windowId;
    }
    get webContentsId() {
        return this._webContentsId;
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(electron_2.IElectronMainUIService),
    tslib_1.__metadata("design:type", Object)
], ElectronPlainWebviewWindow.prototype, "electronMainUIService", void 0);
ElectronPlainWebviewWindow = tslib_1.__decorate([
    (0, di_1.Injectable)({ multiple: true }),
    tslib_1.__metadata("design:paramtypes", [Object, Object])
], ElectronPlainWebviewWindow);
exports.ElectronPlainWebviewWindow = ElectronPlainWebviewWindow;
//# sourceMappingURL=webview-window.js.map