import { Disposable, IEventBus, ILogger, IStorage, StorageProvider, URI } from '@opensumi/ide-core-browser';
import { IEditorGroup, IResource, WorkbenchEditorService } from '@opensumi/ide-editor';
import { EditorComponentRegistry, EditorPreferences } from '@opensumi/ide-editor/lib/browser';
import { IEditorWebviewComponent, IEditorWebviewMetaData, IPlainWebview, IPlainWebviewComponentHandle, IPlainWebviewConstructionOptions, IPlainWebviewWindow, IWebview, IWebviewContentOptions, IWebviewReviver, IWebviewService, IWebviewThemeData } from './types';
import type { ITheme } from '@opensumi/ide-theme';
export declare class WebviewServiceImpl implements IWebviewService {
    private webviewIdCount;
    private editorWebviewIdCount;
    readonly editorWebviewComponents: Map<string, EditorWebviewComponent<IWebview | IPlainWebview>>;
    readonly plainWebviewsComponents: Map<string, IPlainWebviewComponentHandle>;
    private readonly webviews;
    private injector;
    private readonly appConfig;
    protected readonly editorPreferences: EditorPreferences;
    private _revivers;
    logger: ILogger;
    getStorage: StorageProvider;
    storage: Promise<IStorage>;
    constructor();
    tryReviveWebviewComponent(id: string): Promise<void>;
    registerWebviewReviver(reviver: IWebviewReviver): import("@opensumi/ide-core-browser").IDisposable;
    createPlainWebview(options?: IPlainWebviewConstructionOptions): IPlainWebview;
    createWebview(options?: IWebviewContentOptions): IWebview;
    getWebview(id: string): IWebview | undefined;
    private storeWebviewResource;
    tryRestoredWebviewComponent(id: string): Promise<void>;
    createEditorWebviewComponent(options?: IWebviewContentOptions, id?: string, metadata?: Record<string, any>): IEditorWebviewComponent<IWebview>;
    createEditorPlainWebviewComponent(options: IPlainWebviewConstructionOptions | undefined, id: string): IEditorWebviewComponent<IPlainWebview>;
    getWebviewThemeData(theme: ITheme): IWebviewThemeData;
    getOrCreatePlainWebviewComponent(id: string, options?: IPlainWebviewConstructionOptions | undefined): IPlainWebviewComponentHandle;
    getEditorPlainWebviewComponent(id: string): IEditorWebviewComponent<IPlainWebview> | undefined;
    getPlainWebviewComponent(id: string): IPlainWebviewComponentHandle | undefined;
    createWebviewWindow(options?: Electron.BrowserWindowConstructorOptions, env?: {
        [key: string]: string;
    }): IPlainWebviewWindow;
}
export declare class EditorWebviewComponent<T extends IWebview | IPlainWebview> extends Disposable implements IEditorWebviewComponent<T> {
    readonly id: string;
    webviewFactory: () => T;
    readonly metadata?: Record<string, any> | undefined;
    workbenchEditorService: WorkbenchEditorService;
    editorComponentRegistry: EditorComponentRegistry;
    eventBus: IEventBus;
    private _webview;
    private _onDidUpdateResource;
    readonly onDidUpdateResource: import("@opensumi/ide-core-browser").Event<IResource<IEditorWebviewMetaData>>;
    private _onDidChangeGroupIndex;
    onDidChangeGroupIndex: import("@opensumi/ide-core-browser").Event<number>;
    private _supportsRevive;
    get supportsRevive(): boolean;
    set supportsRevive(value: boolean);
    open(options: {
        groupIndex?: number;
        relativeGroupIndex?: number;
    }): Promise<import("@opensumi/ide-editor").IOpenResourceResult>;
    close(): void;
    private _title;
    private _icon;
    get icon(): string;
    set icon(icon: string);
    get title(): string;
    set title(title: string);
    get webview(): T;
    get resource(): IResource<IEditorWebviewMetaData>;
    get webviewUri(): URI;
    get editorGroup(): IEditorGroup | undefined;
    get group(): IEditorGroup | undefined;
    get componentId(): string;
    constructor(id: string, webviewFactory: () => T, metadata?: Record<string, any> | undefined);
    createWebview(): T;
    clear(): void;
}
export declare class PlainWebviewComponent extends Disposable implements IPlainWebviewComponentHandle {
    readonly id: string;
    readonly webview: any;
    constructor(id: string, webview: any);
}
//# sourceMappingURL=webview.service.d.ts.map