"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ElectronWebviewChannel = void 0;
const electron_1 = require("electron");
const webview_manager_1 = require("../webview-host/webview-manager");
class ElectronWebviewChannel {
    constructor() {
        this.handlers = new Map();
        this.fakeLoad = false;
        this.isInDevelopmentMode = false;
        window.addEventListener('message', (e) => {
            if (e.data && (e.data.command === 'onmessage' || e.data.command === 'do-update-state')) {
                // Came from inner iframe
                this.postMessage(e.data.command, e.data.data);
                return;
            }
            const channel = e.data.channel;
            const handler = this.handlers.get(channel);
            if (handler) {
                handler(e, e.data.data);
            }
            else {
                // eslint-disable-next-line no-console
                console.warn('no handler for ', e);
            }
        });
        this.ready = new Promise((resolve) => {
            resolve();
        });
        this.onMessage('devtools-opened', () => {
            this.isInDevelopmentMode = true;
        });
    }
    postMessage(channel, data) {
        electron_1.ipcRenderer.sendToHost(channel, data);
    }
    onMessage(channel, handler) {
        electron_1.ipcRenderer.on(channel, handler);
    }
    onIframeLoaded(newFrame) {
        // newFrame.contentWindow.onbeforeunload = () => {
        //   if (this.isInDevelopmentMode) { // Allow reloads while developing a webview
        //     this.postMessage('do-reload');
        //     return false;
        //   }
        //   // Block navigation when not in development mode
        //   console.log('prevented webview navigation');
        //   return false;
        // };
    }
}
exports.ElectronWebviewChannel = ElectronWebviewChannel;
new webview_manager_1.WebviewPanelManager(new ElectronWebviewChannel());
//# sourceMappingURL=host-channel.js.map